**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name             Primal2
Sequence         1 - Introduction to mathematical programming using GAMS
Type             LP
GAMS language    Zero value in a matrix, write a variable to the right or left  of a constraint, indifferently.
Description
Loosening the labour constraint
" A given farm can produce two crops: wheat and maize.
We are looking to determine the area dedicated to each crop, knowing that:
The farmer's objective is to maximize his income
The yield of wheat is 5 tonnes per hectare and that of maize 10 tonnes.
Their production costs are 300/ha and 500/ha, respectively.
Both cereals are sold at 150/tonne.
Wheat requires 25 hours of labour per hectare and per year and maize 50 hours of labour .
The area of the farm is 50 ha and the farmer can work 2000 hours in a year.
The farmer can hire workers at 15/h."

$Offtext
*-----------------------------------------------------------------------------*


*~~~~~~~~~~~~~~~~~~~~~~~~ DECLARATION ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*
sets
C crops  /wheat,maize/
;

*~~~~~~~~~~~~~~~~~~~~~~~~ DATA ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*
scalar
LAND_A      land availability in hectares                 /50/
LABOUR_A    labour availability in hours                  /2000/
PSLF        hourly price of the hired labour              /15/
;

parameter
LN(C) labour needs per hectare and per crop (hours)
/wheat   25
 maize   50/

GM(C) gross margin per crop (euros)
/wheat   450
 maize  1000/
;

*~~~~~~~~~~~~~~~~~~~~~~~~ MODEL  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*
variables
Z   total farm income  (euros)
;

positive variables
X   area per crop (hectares)
SLF number of hours of hired labour  (hours)
;

equations
OBJECTIVE       objective function
LAND            land equation
LABOUR          labour equation
;

OBJECTIVE..     sum(c, GM(c)*X(c)) - PSLF*SLF =E= Z ;

LAND..          sum(c, X(c)) =l= LAND_A ;

LABOUR..        sum(c, LN(c)*X(c)) =L= LABOUR_A + SLF ;


model example first example /all/;

*~~~~~~~~~~~~~~~~~~~~~~~~ SOLUTION ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*
solve example using LP maximizing Z;



parameter RESULT(*,*);
RESULT('LAND','TOTAL') = LAND.L;
RESULT('LAND','MARGINAL') = LAND.M;
RESULT('LABOUR','TOTAL') = LABOUR.L;
RESULT('LABOUR','MARGINAL') = LABOUR.M;
display result;
